@@ -2,4 +2,4 @@
 
 extern crate alloc;
 
-pub mod parser;
+pub mod text;
